# BM16036UNO

**BM16036UNO** Es una librería en Python diseñada para resolver sistemas de ecuaciones lineales y no lineales utilizando diversos métodos numéricos. Esta librería fue desarrollada como parte del Corto 1 de la materia Cálculo Numérico para Desarrollo de Aplicaciones para la Universidad Nacional de El Salvador, agrupa implementaciones de métodos clásicos, tales como:

- **Eliminación de Gauss**
- **Gauss-Jordan**
- **Cramer**
- **Descomposición LU**
- **Jacobi**
- **Gauss-Seidel**
- **Bisección**

## Características

- **Resolución de sistemas lineales:**  
  Implementa métodos directos (Eliminación de Gauss, Gauss-Jordan, Cramer, Descomposición LU) e iterativos (Jacobi y Gauss-Seidel) para resolver sistemas de ecuaciones.

- **Resolución de ecuaciones no lineales:**  
  Incluye el método de bisección para encontrar raíces de funciones no lineales.



